DECLARE FUNCTION RH! (Temp!, DewPoint!)

'$page
'***************************************************************************
'
'       This relative humidity algorithm is an adaptation of a
'       FORTRAN routine used by the National Weather Service.
'       I'm sure there are other quick and dirty methods of
'       calculating Relative Humidity but this one works and is
'       *very* accurate.
'
'       Questions or comments contact:      
'
'                               Jim Little
'                               Compuserve 72765,1431
'                               c/o KATU-TV
'                               Portland, Oregon 97232
'
'    
'***************************************************************************
FUNCTION RH (Temp, DewPoint) STATIC

		IF DewPoint > Temp THEN                 'Return -1 as error code
				RH = -1                         '   if dewpoint greater
				GOTO RelHumidEnd                '   than temperature
		END IF

		T = (Temp - 32) * 5 / 9                 'Convert to celsius
		D = (DewPoint - 32) * 5 / 9
	   
		C1# = .9999968299999999#                'set constants
		C2# = -.0090826951#
		C3# = .000078736169#
		C4# = -.00000061117958#
		C5# = .0000000043884187#
		C6# = -2.9883885D-11
		C7# = 2.1874425D-13
		C8# = -1.7892321D-15
		C9# = 1.1112018D-17
		C10# = -3.0994571D-20
	   
		X1# = C10#
		X1# = C9# + T * (X1#)
		X1# = C8# + T * (X1#)
		X1# = C7# + T * (X1#)
		X1# = C6# + T * (X1#)
		X1# = C5# + T * (X1#)
		X1# = C4# + T * (X1#)
		X1# = C3# + T * (X1#)
		X1# = C2# + T * (X1#)
		X1# = C1# + T * (X1#)
		X1# = X1# ^ 8

		X2# = C10#
		X2# = C9# + D * (X2#)
		X2# = C8# + D * (X2#)
		X2# = C7# + D * (X2#)
		X2# = C6# + D * (X2#)
		X2# = C5# + D * (X2#)
		X2# = C4# + D * (X2#)
		X2# = C3# + D * (X2#)
		X2# = C2# + D * (X2#)
		X2# = C1# + D * (X2#)
		X2# = X2# ^ 8



		RH = 100 * X1# / X2#                    'express results as percent

RelHumidEnd:

END FUNCTION

